Attribute VB_Name = "modImExport"
'------------------------------------------------------------------------------
'---------------------------Im- und Export Visitenkarten---------------------------
'------------------------------------------------------------------------------
'
'Author:    Daniel Frauenrath
'Mail:      daniel.frauenrath@cedas.de
'Release:   21.05.2012
'Version:   1.0
'
'********************************************************************************
'<<<<<<<<<<<<<<<<<<<<<<<<<<Beschreibung / Discription>>>>>>>>>>>>>>>>>>>>>>>>>>>>
'********************************************************************************
'DE: Importiert oder exportiert Visitenkarten (*.vcard) von bzw. nach Outlook
'
'*********************************************************************************
'<<<<<<<<<<<<<<<<<<<<<<<<<<Vernderungen / Change log>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
'*********************************************************************************
'Autor:                     Datum:          Zeile:      Modul:       Anmerkung:
'Daniel Frauenrath          21.05.2012      Alle        Alle         Neuerstellung
'
'**********************************************************************************


'***ROUTINE ZUM EXPORTIEREN VON VISITENKARTEN
Public Sub ExportContacts()

    '***FEHLERBEHANDLUNG
    On Error Resume Next
    
    '***DEKLARATIONEN
    Dim objSelection As Selection
    Dim objItem As ContactItem
    Dim olType As Variant: olType = olVCard
    Dim strEndung As String: strEndung = ".vcf"
    Dim strSaveName As String
    Dim objFolderBrowser As New clsBrowseFolder
    Dim strSavePath As String
    Dim lngExportedContacts As Long
    Dim lngFailContacts As Long
    Dim vbAbfrageDatei As VbMsgBoxResult
    
    '***SELEKTIONSOBJEKT BEREITSTELLEN
    Set objSelection = Application.ActiveExplorer.Selection
    If objSelection.Count = 0 Then
        MsgBox "Es wurden keine Objekte (Kontakte) ausgewhlt", vbExclamation, "Keine Kontakte ausgewhlt"
        Exit Sub
    End If

    '***SPEICHERPFAD DURCH AUSWAHL (ORDNER)
    strSavePath = objFolderBrowser.FuncBrowseFolder(Caption:="Bitte Export-Ordner auswhlen")
    If strSavePath = vbNullString Then
        MsgBox "Die Ordnerauswahl wurde abgebrochen", vbExclamation, "ABBRUCH DURCH ANWENDER"
        Exit Sub
    Else
        If Right(strSavePath, 1) <> "\" Then
            strSavePath = strSavePath & "\"
        End If
    End If

    '***SCHLEIFE DURCH SELEKTION -> EXPORT
    For Each objItem In objSelection
        '***DATEINAMEN LESEN
        strSaveName = objItem.FileAs
        
        '***ABFRAGE EXISTENZ IN SELBEN ORDNER (UEBERSCHREIBEN?)
        If FuncCheckFileExits(strSavePath & strSaveName & strEndung) = True Then
            vbAbfrageDatei = MsgBox("Die zu exportierende Datei " & strSaveName & " existiert bereits im angegebenen Ordner!" + vbNewLine + _
                                    "Wollen Sie diese Datei berschreiben?", vbYesNo + vbQuestion, "Visitenkarte berschreiben?")
            If vbAbfrageDatei = vbYes Then
                objItem.SaveAs strSavePath & strSaveName & strEndung, olType
                lngExportedContacts = lngExportedContacts + 1
            End If
        Else
            objItem.SaveAs strSavePath & strSaveName & strEndung, olType
            lngExportedContacts = lngExportedContacts + 1
        End If
        If Err.Number <> 0 Then
            lngFailContacts = lngFailContacts + 1
            Err.Clear
        End If
    Next
    
    '***AUSGABE
    If lngFailContacts = 0 Then
        MsgBox "Es wurde(n) " & CStr(lngExportedContacts) & " Kontakt(e) in folgendes Verzeichnis exportiert:" + vbNewLine + vbNewLine + _
                strSavePath, vbInformation, CStr(lngExportedContacts) & " Kontakt(e) erfolgreich exportiert"
    Else
        MsgBox "Es wurde(n) " & CStr(lngExportedContacts) & " Kontakt(e) in folgendes Verzeichnis exportiert:" + vbNewLine + vbNewLine + _
                strSavePath + vbNewLine + vbNewLine + _
                CStr(lngFailContacts) & " Kontakt(e) konnten nicht exportiert werden", vbExclamation, CStr(lngExportedContacts) & " Kontakt(e) erfolgreich exportiert"
    End If


End Sub

'***ROUTINE ZUM IMPORTIEREN VON VISITENKARTEN
Public Sub ImportContacts()

    '***FEHLERBEHANDLUNG
    'On Error Resume next
    
    '***DEKLARATIONEN
    Dim objWSHShell As IWshRuntimeLibrary.IWshShell
    Dim colInsp As Outlook.Inspectors
    Dim strVCName As String
    Dim objFileSystem As Scripting.FileSystemObject
    Dim objInputDir As Scripting.Folder
    Dim objInputFile As Scripting.File
    Dim vCounter As Integer
    Dim strImportPath As String
    Dim objFolderBrowser As New clsBrowseFolder
    Dim lngImportContacts As Long
    Dim lngFailContacts As Long
    
    '***IMPORTPFAD DURCH AUSWAHL (ORDNER)
    strImportPath = objFolderBrowser.FuncBrowseFolder(Caption:="Bitte Import-Ordner auswhlen")
    If strImportPath = vbNullString Then
        MsgBox "Die Ordnerauswahl wurde abgebrochen", vbExclamation, "ABBRUCH DURCH ANWENDER"
        Exit Sub
    Else
        If Right(strImportPath, 1) <> "\" Then
            strImportPath = strImportPath & "\"
        End If
    End If
    
    '***ZUGRIFF AUF FILESYSTEM
    Set objFileSystem = New Scripting.FileSystemObject
    Set objInputDir = objFileSystem.GetFolder(strImportPath)

    '***VISITENKARTEN IMPORTIEREN (BATCH)
    For Each objInputFile In objInputDir.Files
        '***DATEITYP PRUEFEN
        If objInputFile.Type = "vCard File" Then
            strVCName = strImportPath & objInputFile.Name
            Set colInsp = Outlook.Inspectors
                If colInsp.Count = 0 Then
                    Set objWSHShell = CreateObject("WScript.Shell")
                    objWSHShell.Run Chr(34) & strVCName & Chr(34)
                    Set colInsp = Outlook.Inspectors
                    If Err = 0 Then
                        Do Until colInsp.Count = 1
                            DoEvents
                        Loop
                        colInsp.Item(1).CurrentItem.Save
                        colInsp.Item(1).Close olDiscard
                        Set colInsp = Nothing
                        Set objOL = Nothing
                        Set objWSHShell = Nothing
                        lngImportContacts = lngImportContacts + 1
                    Else
                        lngFailContacts = lngFailContacts + 1
                    End If
                End If
        End If
    Next

    '***AUSGABE
    If lngFailContacts = 0 Then
        MsgBox "Es wurde(n) " & CStr(lngImportContacts) & " Kontakt(e) erfolgreich in das Outlook-Adressbuch importiert", _
                vbInformation, CStr(lngImportContacts) & " Kontakt(e) erfolgreich importiert"
    Else
        MsgBox "Es wurde(n) " & CStr(lngImportContacts) & " Kontakt(e) erfolgreich in das Outlook-Adressbuch importiert" + vbNewLine + vbNewLine + _
                CStr(lngFailContacts) & " Kontakt(e) konnten nicht importiert werden", vbExclamation, CStr(lngImportContacts) & " Kontakt(e) erfolgreich importiert"
    End If
End Sub


'***FUNKTION ZUM PRUEFEN OB DATEI BEREITS EXISTIERT
Private Function FuncCheckFileExits(ByVal strFileName As String) As Boolean

    If Dir(strFileName) = "" Then
        FuncCheckFileExits = False 'DATEI EXISTIERT NICHT
      Else
        FuncCheckFileExits = True ' DATEI EXISTIERT
    End If
    
End Function
